uniform sampler2D textureY;
uniform sampler2D textureUV;
uniform sampler2D textureRGBA;
uniform sampler2D texRGBALookup;
varying vec2 textureCoordinate;
uniform float pixFormat;				
uniform int lookup;						

vec4 NV12toRGBA(vec2 inCoordinate)
{
	vec3 yuv;
	vec3 rgb;
	yuv.x = texture2D(textureY, inCoordinate).r -16./256.;
	yuv.y = texture2D(textureUV, inCoordinate).r - 128./256.;
	yuv.z = texture2D(textureUV, inCoordinate).g - 128./256.;
	rgb = mat3( 1,       1,         1,
                0,       -0.39465,  2.03211,
                1.13983, -0.58060,  0) * yuv;
	return vec4(rgb, 1);
}



void main()
{
	vec4 textureColor;
	vec4 textureAlphaColor;
	
	if(pixFormat == 1000.0)
	{
		textureColor = vec4(texture2D(textureRGBA,textureCoordinate));		
	}
	else
	{
		//YUV
		textureColor = NV12toRGBA(textureCoordinate);
	}
			
	if(lookup == 1)
	{
   		float blueColor = textureColor.b * 63.0;
 
    	vec2 quad1;
    	quad1.y = floor(floor(blueColor) / 8.0);
    	quad1.x = floor(blueColor) - (quad1.y * 8.0);
 
    	vec2 quad2;
    	quad2.y = floor(ceil(blueColor) / 8.0);
    	quad2.x = ceil(blueColor) - (quad2.y * 8.0);
 
    	vec2 texPos1;
    	texPos1.x = (quad1.x * 0.125) + 0.5/512.0 + ((0.125 - 1.0/512.0) * textureColor.r);
    	texPos1.y = (quad1.y * 0.125) + 0.5/512.0 + ((0.125 - 1.0/512.0) * textureColor.g);
 
    	vec2 texPos2;
    	texPos2.x = (quad2.x * 0.125) + 0.5/512.0 + ((0.125 - 1.0/512.0) * textureColor.r);
    	texPos2.y = (quad2.y * 0.125) + 0.5/512.0 + ((0.125 - 1.0/512.0) * textureColor.g);
 
    	vec4 newColor1 = texture2D(texRGBALookup, texPos1);
    	vec4 newColor2 = texture2D(texRGBALookup, texPos2);
 
    	vec4 newColor = mix(newColor1, newColor2, fract(blueColor));
		//gl_FragColor = vec4(newColor.rgb, textureColor.w);	
		textureColor = mix(textureColor, vec4(newColor.rgb, textureColor.w), 1.0);
	}
		
	gl_FragColor = textureColor;	
}
